
#include "device_registers.h"           /* Device header */
#include "cmsis_os2.h"                  /* ::CMSIS:RTOS2 */

extern void                 app_main (void *arg);
extern uint64_t             app_main_stk[];
extern const osThreadAttr_t app_main_attr;


/*----------------------------------------------------------------------------
  configure SystemCoreClock:
     System Clock source         PLL (OSC)
     OSC Frequency(Hz)           8000000
     SYSCLK(Hz)                  96000000
     PLLMUL                      24
     PREDIV                      2
 *----------------------------------------------------------------------------*/
void SystemCoreClockConfigure(void) {

  SCG->SOSCCSR = SCG_SOSCCSR_SOSCERR(1U);

  /* set up OSC clock. */
  /* Setup dividers. */
  SCG->SOSCDIV = (SCG_SOSCDIV_SOSCDIV1(1U) |
                  SCG_SOSCDIV_SOSCDIV2(1U)  );

  /* Set OSC configuration. */
  SCG->SOSCCFG = (SCG_SOSCCFG_EREFS(1U) |
                  SCG_SOSCCFG_RANGE(2U)  );

  /* Enable clock. */
  SCG->SOSCCSR = (SCG_SOSCCSR_SOSCEN(1U) );

  /* Wait for OSC clock to be valid. */
  while (!(SCG->SOSCCSR & SCG_SOSCCSR_SOSCVLD(1U))) __NOP();

 /* Init SIRC */
  SCG->SIRCCSR = 0U;

  /* Setup dividers. */
  SCG->SIRCDIV = (SCG_SIRCDIV_SIRCDIV1(1U) |
                  SCG_SIRCDIV_SIRCDIV2(2U)  );

  /* Set SIRC configuration. */
  SCG->SIRCCFG = SCG_SIRCCFG_RANGE(1U);

  /* Enable clock. */
  SCG->SIRCCSR = SCG_SIRCCSR_SIRCEN(1U);

  /* Wait for SIRC clock to be valid. */
  while (!(SCG->SIRCCSR & SCG_SIRCCSR_SIRCVLD(1U))) __NOP();

  /* Change to SIRC as system clock source */
  SCG->RCCR = (SCG_RCCR_DIVSLOW(3U) |
               SCG_RCCR_DIVBUS(0U)  |
               SCG_RCCR_DIVCORE(0U) |
               SCG_RCCR_SCS(2U)     );

  /* Wait for clock source switch finished. */
  while ((SCG->RCCR & 0x0F000000) != 0x02000000) __NOP();;

  /* Init Firc */
  SCG->FIRCCSR = 0U;

  /* Setup dividers. */
  SCG->FIRCDIV = (SCG_FIRCDIV_FIRCDIV1(1U) |
                  SCG_FIRCDIV_FIRCDIV2(1U)  );

  /* Set FIRC configuration. */
  SCG->FIRCCFG = SCG_FIRCCFG_RANGE(0U);

  /* Enable clock. */
  SCG->FIRCCSR |= SCG_FIRCCSR_FIRCEN(1U);

  /* Wait for FIRC clock to be valid. */
  while (!(SCG->FIRCCSR & SCG_FIRCCSR_FIRCVLD(1U))) __NOP();;

  /* Init SysPll */
  SCG->SPLLCSR = SCG_SPLLCSR_SPLLERR(1U);

  /* Setup dividers. */
  SCG->SPLLDIV = (SCG_SPLLDIV_SPLLDIV1(1U) |
                  SCG_SPLLDIV_SPLLDIV2(2U)  );

  /* Set PLL configuration. */
  SCG->SPLLCFG = (SCG_SPLLCFG_PREDIV(0U) |                     /* prediv 1 */
                  SCG_SPLLCFG_MULT(8U)   );                    /* pll multiply 24 */

  /* Enable clock. */
  SCG->SPLLCSR = SCG_SPLLCSR_SPLLEN(1U);

  /* Wait for PLL clock to be valid. */
  while (!(SCG->SPLLCSR & SCG_SPLLCSR_SPLLVLD(1U))) __NOP();

  /* Change to use PLL as system clock source */
  SCG->RCCR = (SCG_RCCR_DIVSLOW(4U) |
               SCG_RCCR_DIVBUS(1U)  |
               SCG_RCCR_DIVCORE(0U) |
               SCG_RCCR_SCS(6U)     );

  /* Wait for clock source switch finished. */
  while ((SCG->RCCR & 0x0F000000) != 0x06000000) __NOP();
}

/*----------------------------------------------------------------------------
  main function
 *---------------------------------------------------------------------------*/
int main(void)
{
  SystemCoreClockConfigure();                                  /* configure system core clock */
  SystemCoreClockUpdate();                                     /* update System Core Clock info */

  osKernelInitialize();                                        /* initialize CMSIS-RTOS */
                                                               /* create application main thread */
  osThreadNew(app_main, NULL, &app_main_attr);
  if (osKernelGetState() == osKernelReady) {
    osKernelStart();                                           /* start thread execution */
  }
  for (;;);
}
